==> wls-plugin-3.0.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/WlsStepBase.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import org.springframework.core.io.ClassPathResource;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.StepExecutionContextCallbackHandler;
import com.xebialabs.deployit.hostsession.CommandExecutionCallbackHandler;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;

@SuppressWarnings("serial")
public abstract class WlsStepBase implements Step {

	public static final String STEP_RESOURCES_PATH = "com/xebialabs/deployit/plugin/wls/step/";

	protected String description;

	protected WlsDomain domain;

	protected WlsStepBase(WlsDomain domain) {
		this.domain = domain;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public int executeWlstJythonScriptResource(StepExecutionContext ctx, HostSession s, String scriptResourcePath, String... args) {
		String scriptPath = s.copyToTemporaryFile(new ClassPathResource(scriptResourcePath)).getPath();
		CommandExecutionCallbackHandler handler = new StepExecutionContextCallbackHandler(ctx);
		return domain.executeWlstJythonScript(handler, s, scriptPath, args);
	}

	public int executeWlstJythonScriptResource(StepExecutionContext ctx, String scriptResourcePath, String... args) {
		HostSession s = domain.connectToAdminHost();
		try {
			return executeWlstJythonScriptResource(ctx, s, scriptResourcePath, args);
		} finally {
			s.close();
		}
	}

}

==> wls-plugin-3.0.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/WlsStepBase.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.hostsession.CmdLine;
import org.springframework.core.io.ClassPathResource;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.StepExecutionContextCallbackHandler;
import com.xebialabs.deployit.hostsession.CommandExecutionCallbackHandler;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;

@SuppressWarnings("serial")
public abstract class WlsStepBase implements Step {

	public static final String STEP_RESOURCES_PATH = "com/xebialabs/deployit/plugin/wls/step/";

	protected String description;

	protected WlsDomain domain;

	protected WlsStepBase(WlsDomain domain) {
		this.domain = domain;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public int executeWlstJythonScriptResource(StepExecutionContext ctx, HostSession s, String scriptResourcePath, CmdLine cmdLine) {
		String scriptPath = s.copyToTemporaryFile(new ClassPathResource(scriptResourcePath)).getPath();
		CommandExecutionCallbackHandler handler = new StepExecutionContextCallbackHandler(ctx);
		return domain.executeWlstJythonScript(handler, s, scriptPath, cmdLine);
	}

	public int executeWlstJythonScriptResource(StepExecutionContext ctx, String scriptResourcePath, CmdLine cmdLine) {
		HostSession s = domain.connectToAdminHost();
		try {
			return executeWlstJythonScriptResource(ctx, s, scriptResourcePath, cmdLine);
		} finally {
			s.close();
		}
	}

}
